## # # # # # # # # # # # # # # # # # # # # # # # #
##
## Project: Ageing of PLBs and NABs
##
## Script name: Ageing.R
##
## Purpose of script: data analysis of ageing data
##
## Author: Jeroen Bauwens
##
## 
##
## # # # # # # # # # # # # # # # # # # # # # # # #



## Libraries ----
library(xlsx)
library(pls)
library(viridis)
library(ggplot2)
library(ggrepel)
library(qvalue)
library(reshape2)
library(pracma)
library(wesanderson)


## Folders and filenames ----
data.dir   <- "./Data/"
output.dir <- "./Output_R/"
source("./Functions/PLSRplot.R")
source("./Functions/PCbiplot_all.R")
source("./Functions/PCbiplot_aldehydes.R")
source("./Functions/VolcanoPlot.R")
source("./Functions/PLSRplot_OAS.R")
source("./Functions/BonBoxplot.R")
source("./Functions/BonBoxplot_sens.R")
source("./Functions/LinRegCurve.R")
source("./Functions/LinRegCurveExcl.R")


## Data wrangling fresh beers -----

# read in data fresh
data_F <- read.xlsx("./Data/Analytical.xlsx",
                    sheetIndex = "Fresh",
                    check.names = F,
                    stringsAsFactors = F)

# set names (we add compound class after 'xxx' to use later)
names(data_F)<-paste0(data_F[1,],"xxx",data_F[2,])

# set bd to 0
data_F <- data.frame(lapply(data_F, function(x) {
  gsub("^nd", 0, x)
}),stringsAsFactors = F, check.names = F)

# Subset for means and SD 
data_F_mean <- data_F[,(data_F[3,] != "SD")]
data_F_SD <- data_F[,data_F[3,] != "Mean"]

# Remove unnecessary rows
data_F_mean<-data_F_mean[-c(1:3),]
data_F_SD<-data_F_SD[-c(1:3),]

# change chr to numeric values 
for (i in 2: ncol(data_F_mean)){
  data_F_mean[,i]<-as.numeric(data_F_mean[,i])
}
for (i in 2: ncol(data_F_SD)){
  data_F_SD[,i]<-as.numeric(data_F_SD[,i])
}

# apply rownames and remove first column
rownames(data_F_mean)<-data_F_mean$Code
data_F_mean<-data_F_mean[,-1]
rownames(data_F_SD)<-data_F_SD$Code
data_F_SD<-data_F_SD[,-1]


## Data wrangling aged beers -----
# Read in data aged
data_A <- read.xlsx("./Data/Analytical.xlsx",
                    sheetIndex = "Aged",
                    check.names = F,
                    stringsAsFactors = F
)

# set names (we add compound class after 'xxx' to use later)
names(data_A)<-paste0(data_A[1,],"xxx",data_A[2,])
# Remove nd
data_A <- data.frame(lapply(data_A, function(x) {
  gsub("^nd", 0, x)
}),stringsAsFactors = F,check.names = F)

# Subset for means and SD 
data_A_mean <- data_A[,data_A[3,] != "SD"]
data_A_SD <- data_A[,data_A[3,] != "Mean"]

# Remove unnecessary rows
data_A_mean<-data_A_mean[-c(1:3),]
data_A_SD<-data_A_SD[-c(1:3),]

# Define compound class
compound_class_A<-substring(names(data_A_mean), as.numeric(gregexpr("xxx", names(data_A_mean)))+3)
compound_class_A<-compound_class_A[-1]

# Change chr to numeric values 
for (i in 2: ncol(data_A_mean)){
  data_A_mean[,i]<-as.numeric(data_A_mean[,i])
}
for (i in 2: ncol(data_A_SD)){
  data_A_SD[,i]<-as.numeric(data_A_SD[,i])
}

# apply rownames and remove first column
rownames(data_A_mean)<-data_A_mean$Code
data_A_mean<-data_A_mean[,-1]
rownames(data_A_SD)<-data_A_SD$Code
data_A_SD<-data_A_SD[,-1]


## perform PCA on all aged and fresh beers on the common parameters (Fig 1) ----
# define common parameters
common_parameters<-intersect(names(data_F_mean),names(data_A_mean))
# select common parameters in fresh beer data set
data_F_alsoA<-data_F_mean[,common_parameters]
# make data frame for PCA
data_PCA<-rbind(data_F_alsoA,data_A_mean)
# G/G0 doesnt have bitter acid data (interferences in chromatograms), for PCA we put their values equal to the mean of all beers (best guess)
data_PCA[grep("G_F",rownames(data_PCA)),grep("bitter",names(data_PCA))]<-colMeans(data_PCA[-grep("G",rownames(data_PCA)),grep("bitter",names(data_PCA))])
data_PCA[grep("G_A",rownames(data_PCA)),grep("bitter",names(data_PCA))]<-colMeans(data_PCA[-grep("G",rownames(data_PCA)),grep("bitter",names(data_PCA))])
data_PCA[grep("G0_F",rownames(data_PCA)),grep("bitter",names(data_PCA))]<-colMeans(data_PCA[-grep("G",rownames(data_PCA)),grep("bitter",names(data_PCA))])
data_PCA[grep("G0_A",rownames(data_PCA)),grep("bitter",names(data_PCA))]<-colMeans(data_PCA[-grep("G",rownames(data_PCA)),grep("bitter",names(data_PCA))])
# fix names
names(data_PCA)<-substring(names(data_PCA), 1,as.numeric(gregexpr("xxx", names(data_PCA)))-1)
# perform PCA
PCA <- prcomp(data_PCA, scale = TRUE)
PCbiplot_all(PCA,"PC1", "PC2","Fig 1 - PCA_all_beers -",compound_class_A)




## Perform volcano analyses (Fig 2) ----

data_F_volcano<-data_F_alsoA
data_A_volcano<-data_A_mean
names(data_F_volcano)<-substring(names(data_F_alsoA), 1,as.numeric(gregexpr("xxx", names(data_F_alsoA)))-1)
names(data_A_volcano)<-substring(names(data_A_mean), 1,as.numeric(gregexpr("xxx", names(data_A_mean)))-1)


# volcano on PLB 
data_F_PLB_volcano<-data_F_alsoA[-grep("0",rownames(data_F_alsoA)),]
data_A_PLB_volcano<-data_A_mean[-grep("0",rownames(data_A_mean)),]
names(data_F_PLB_volcano)<-substring(names(data_F_PLB_volcano), 1,as.numeric(gregexpr("xxx", names(data_F_PLB_volcano)))-1)
names(data_A_PLB_volcano)<-substring(names(data_A_PLB_volcano), 1,as.numeric(gregexpr("xxx", names(data_A_PLB_volcano)))-1)
volcano.plot(data_F_PLB_volcano,data_A_PLB_volcano,0.05,"Fig 2 - Volcano_PLB",1)

## volcano on NAB
data_F_NAB_volcano<-data_F_alsoA[grep("0",rownames(data_F_alsoA)),]
data_A_NAB_volcano<-data_A_mean[grep("0",rownames(data_A_mean)),]
names(data_F_NAB_volcano)<-substring(names(data_F_NAB_volcano), 1,as.numeric(gregexpr("xxx", names(data_F_NAB_volcano)))-1)
names(data_A_NAB_volcano)<-substring(names(data_A_NAB_volcano), 1,as.numeric(gregexpr("xxx", names(data_A_NAB_volcano)))-1)
volcano.plot(data_F_NAB_volcano,data_A_NAB_volcano,0.05,"Fig 2 - Volcano_NAB",1)





## PLS Aldehydes aged in function of all fresh parameters (Fig 4) ------
#define aldehydes aged data frame
Aldehydes_aged<-data_A_mean[,grep("aldehyde",names(data_A_mean))]
#remove sum of aldehydes
Aldehydes_aged<-Aldehydes_aged[,-grep("aldehydesxxxaldehydes",names(Aldehydes_aged))]
#adjust rownames
rownames(Aldehydes_aged)<-gsub("_A","",rownames(Aldehydes_aged))
#make dataframe with results of fresh beers for PLS
AldPLS_matrix<-data_F_mean
#make colour vector for PLS
colour<-substring(names(AldPLS_matrix), as.numeric(gregexpr("xxx", names(AldPLS_matrix)))+3)
# G/G0 doesnt have bitter acid data (interferences in chromatograms), for PCA we put their values equal to the mean of all beers (best guess)
AldPLS_matrix[grep("G_F",rownames(AldPLS_matrix)),grep("bitter",names(AldPLS_matrix))]<-colMeans(AldPLS_matrix[-grep("G",rownames(AldPLS_matrix)),grep("bitter",names(AldPLS_matrix))])
AldPLS_matrix[grep("G_A",rownames(AldPLS_matrix)),grep("bitter",names(AldPLS_matrix))]<-colMeans(AldPLS_matrix[-grep("G",rownames(AldPLS_matrix)),grep("bitter",names(AldPLS_matrix))])
AldPLS_matrix[grep("G0_F",rownames(AldPLS_matrix)),grep("bitter",names(AldPLS_matrix))]<-colMeans(AldPLS_matrix[-grep("G",rownames(AldPLS_matrix)),grep("bitter",names(AldPLS_matrix))])
AldPLS_matrix[grep("G0_A",rownames(AldPLS_matrix)),grep("bitter",names(AldPLS_matrix))]<-colMeans(AldPLS_matrix[-grep("G",rownames(AldPLS_matrix)),grep("bitter",names(AldPLS_matrix))])
#adjust rownames
rownames(AldPLS_matrix)<-gsub("_F","",rownames(AldPLS_matrix))
#adjust names
names(AldPLS_matrix)<-substring(names(AldPLS_matrix), 1,as.numeric(gregexpr("xxx", names(AldPLS_matrix)))-1)
names(Aldehydes_aged)<-c("ALD1_Aged","ALD2_Aged","ALD3_Aged","ALD4_Aged","ALD5_Aged","ALD6_Aged","ALD7_Aged","ALD8_Aged")
#perform PLSR
PLSRplot(AldPLS_matrix,Aldehydes_aged, x="Comp.1", y="Comp.2","Fig 4 - PLSR aldehydes",colour)


## PLS sensory data (Fig 9) ------
# read in data
sensory <- read.xlsx("./Data/sensory.xlsx",
                           sheetIndex = "1",
                           check.names = F,
                           stringsAsFactors = F
)

# extract OAS
OAS<-cbind.data.frame(sensory$OAS)
rownames(OAS)<-sensory[,1]
names(OAS)<-c("OAS")
# make dataframe with all analytical results measured on both fresh and aged beers
names(data_F_alsoA)<-substring(names(data_F_alsoA), 1,as.numeric(gregexpr("xxx", names(data_F_alsoA)))-1)
names(data_A_mean)<-substring(names(data_A_mean), 1,as.numeric(gregexpr("xxx", names(data_A_mean)))-1)
AllAnalytical<-rbind(data_F_alsoA,data_A_mean)
names(AllAnalytical)<-names(data_A_mean)
# G/G0 doesnt have bitter acid data (interferences in chromatograms), for PCA we put their values equal to the mean of all beers (best guess)
AllAnalytical[grep("G_F",rownames(AllAnalytical)),is.na(AllAnalytical[grep("G_F",rownames(AllAnalytical)),])]<-colMeans(AllAnalytical[-grep("G", rownames(AllAnalytical)), is.na(AllAnalytical[grep("G_F", rownames(AllAnalytical)), ])])
AllAnalytical[grep("G0_F",rownames(AllAnalytical)),is.na(AllAnalytical[grep("G0_F",rownames(AllAnalytical)),])]<-colMeans(AllAnalytical[-grep("G", rownames(AllAnalytical)), is.na(AllAnalytical[grep("G0_F", rownames(AllAnalytical)), ])])
AllAnalytical[grep("G_A",rownames(AllAnalytical)),is.na(AllAnalytical[grep("G_A",rownames(AllAnalytical)),])]<-colMeans(AllAnalytical[-grep("G", rownames(AllAnalytical)), is.na(AllAnalytical[grep("G_A", rownames(AllAnalytical)), ])])
AllAnalytical[grep("G0_A",rownames(AllAnalytical)),is.na(AllAnalytical[grep("G0_A",rownames(AllAnalytical)),])]<-colMeans(AllAnalytical[-grep("G", rownames(AllAnalytical)), is.na(AllAnalytical[grep("G0_A", rownames(AllAnalytical)), ])])
# make colour vector
col_vect<-substring(names(data_A_SD), as.numeric(gregexpr("xxx", names(data_A_SD)))+3)
# perform PLSR
PLSRplot_OAS(AllAnalytical,OAS$OAS,"OAS","Comp.1","Comp.2","Fig 9 - PLSR OAS -",col_vect)


## significant difference between ageing scores of PLB and NAB? ------
OAS$Type<-"PLB"
OAS$Type[grep("0",rownames(OAS))]<-"NAB"
OAS_aged<-OAS[grep("_A",rownames(OAS)),]
OAS_fresh<-OAS[grep("_F",rownames(OAS)),]
OAS_NAB<-OAS[grep("0",rownames(OAS)),]
OAS_PLB<-OAS[-grep("0",rownames(OAS)),]
OAS_NAB$Type<-"Fresh"
OAS_NAB$Type[grep("_A",rownames(OAS_NAB))]<-"Aged"
OAS_PLB$Type<-"Fresh"
OAS_PLB$Type[grep("_A",rownames(OAS_PLB))]<-"Aged"

t.test(OAS_fresh$OAS[OAS_fresh$Type=="PLB"],OAS_fresh$OAS[OAS_fresh$Type=="NAB"],paired=T)$p.value
t.test(OAS_aged$OAS[OAS_aged$Type=="PLB"],OAS_aged$OAS[OAS_aged$Type=="NAB"],paired=T)$p.value


## make boxplot of sensory results with Bonferroni corrected p values (Fig 8) ----- 
OAS$Freshness<-"Fresh"
OAS$Freshness[grep("_A",rownames(OAS))]<-"Aged"
names(OAS)<-c("value", "variable","Legend")
BonBoxplot_sens(OAS,"","Median overall ageing score","Fig 8 - OAS",T,F)


## make table with correlations OAS and aldehydes concentrations (Table 5) ------
# make dataframe with aldehydes data
Aldehydes<-AllAnalytical[,grep("ALD",names(AllAnalytical))]
Aldehydes$Freshness<-"Fresh"
Aldehydes[grep("_A",rownames(Aldehydes)),]$Freshness<-"Aged"
Aldehydes$Type<-"PLB"
Aldehydes[grep("0",rownames(Aldehydes)),]$Type<-"NAB"
# make dataframe for correlationq
cor_OAS<-data.frame()
# perform Spearman correlation analysis for PLB, NAB and all beers together
for(i in 1:(ncol(Aldehydes)-2)){
  cor_OAS[i,1]<-cor(Aldehydes[(Aldehydes$Type=="PLB"),i],OAS$value[OAS$variable=="PLB"],method="spearman")
  cor_OAS[i,2]<-cor(Aldehydes[(Aldehydes$Type=="NAB"),i],OAS$value[OAS$variable=="NAB"],method="spearman")
  cor_OAS[i,3]<-cor(Aldehydes[,i],OAS$value,method="spearman")
}
# adjust names and rownames
rownames(cor_OAS)<-names(Aldehydes)[1:8]
names(cor_OAS)<-c("PLB","NAB","PLB+NAB")
# round correlation coefficients
cor_OAS<-round(cor_OAS,2)
#write table
write.xlsx(cor_OAS, paste0(output.dir, "Table 5 - cor_OAS_ald", ".xlsx"),)


## make boxplots of aldehydes (Fig 3), bitter acids (Fig 5) and aroma (Fig 7) data with Bonferroni corrected p values (Fig 8) --------------

##Aldehydes
# make data frame with relative change
Aldehydes_rel<-Aldehydes[grep("_A",rownames(Aldehydes)),grep("ALD",names(Aldehydes))]/Aldehydes[grep("_F",rownames(Aldehydes)),grep("ALD",names(Aldehydes))]*100-100
Aldehydes_rel$Type<-"PLB"
Aldehydes_rel$Type[grep("0",rownames(Aldehydes_rel))]<-"NAB"
# make boxplot
BonBoxplot(Aldehydes_rel,"","Relative change over ageing (%)","Fig 3 - Aldehydes boxplot",T,F)


##Bitteracids
# make data frame with relative change
Bitteracids<-AllAnalytical[-grep("G",rownames(AllAnalytical)),grep("bitter",names(data_A_SD))]
Bitteracids_rel<-(Bitteracids[grep("_A",rownames(Bitteracids)),]/Bitteracids[grep("_F",rownames(Bitteracids)),])*100-100
Bitteracids_rel$Type<-"PLB"
Bitteracids_rel$Type[grep("0",rownames(Bitteracids_rel))]<-"NAB"
#change order of the bitter acids
Bitteracids_rel<-Bitteracids_rel[,c(1,3,5,2,4,6,8,7,9)]
# make boxplot
BonBoxplot(Bitteracids_rel,"","Relative change over ageing (%)","Fig 5 - Bitter acid boxplot",T,F)

#boxplot showing differences in pH values between PLB and NAB
pH<-as.data.frame(data_F_mean[-grep("G",rownames(data_F_mean)),grep("pH",names(data_F_mean))])
rownames(pH)<-rownames(data_F_mean)[1:12]
pH$Type<-"PLB"
pH$Type[grep("0",rownames(pH))]<-"NAB"
names(pH)<-c("","Type")
BonBoxplot(pH,"","pH","Fig 6a",F,F)



##Aroma
# make data frame with relative change
Aroma<-AllAnalytical[,grep("aroma",names(data_A_SD))]
Aroma_rel<-(Aroma[grep("_A",rownames(Aroma)),]/Aroma[grep("_F",rownames(Aroma)),])*100-100
Aroma_rel$Type<-"PLB"
Aroma_rel$Type[grep("0",rownames(Aroma_rel))]<-"NAB"
# make boxplot (only relevant markers)
BonBoxplot(Aroma_rel[,c(5,8:13)],"","Relative change over ageing (%)","Fig 7 - Aroma boxplot",T,F)


## correlation plots (Fig 6 and SFig 1) ----
## decrease trans-iso's as a function of pH
# create folder for output
dir.create("./Output_R/SFig 1 lin reg curves/")
# make data frame with relative change of trans iso-alpha-acids
RelDegBitter <-
  (Bitteracids[grep("_A", rownames(Bitteracids)), grep("t-ich", names(Bitteracids))] +
     Bitteracids[grep("_A", rownames(Bitteracids)), grep("t-ih", names(Bitteracids))] +
     Bitteracids[grep("_A", rownames(Bitteracids)), grep("t-iah", names(Bitteracids))]) /
  (Bitteracids[grep("_F", rownames(Bitteracids)), grep("t-ich", names(Bitteracids))] +
     Bitteracids[grep("_F", rownames(Bitteracids)), grep("t-ih", names(Bitteracids))] +
     Bitteracids[grep("_F", rownames(Bitteracids)), grep("t-iah", names(Bitteracids))]) *
  100 - 100
# make data frame with pH values (G and G0 not included)
pH<-data_F_mean[-(13:14),grep("pH",names(data_F_mean))]
# perform linear regressions
LinRegCurve(pH,RelDegBitter,gsub("_F","",rownames(data_F_mean)[1:12]),"pH",expression(atop("Relative change of",italic("trans")-"iso"-alpha-"acids"~"over"~"ageing"~"(%)")),"Fig 6 - iso_pH","")
LinRegCurve(pH[c(1,3,5,7,9,11)],RelDegBitter[c(1,3,5,7,9,11)],c("A","B","C","D","E","F"),"pH","Relative change over ageing (%)","iso_pH_PLB","SFig 1 lin reg curves/")
LinRegCurve(pH[c(2,4,6,8,10,12)],RelDegBitter[c(2,4,6,8,10,12)],c("A0","B0","C0","D0","E0","F0"),"pH","Relative change over ageing (%)","iso_pH_NAB","SFig 1 lin reg curves/")

## correlations with aldehydes
# make dataframe combining aldehydes in the aged beers and parameters in the fresh beers
names(data_F_mean)<-substring(names(data_F_mean), 1,as.numeric(gregexpr("xxx", names(data_F_mean)))-1)
AldCor<-cbind(Aldehydes_aged,data_F_mean)

#Val-2MP
LinRegCurve(
  AldCor$Val,
  AldCor$ALD1_Aged,
  rownames(AldCor),
  "Valine (mg/L)",
  "2-methylpropanal (g/L)",
  "SFig 1 - val_2MP_all",
  "SFig 1 lin reg curves/"
)
LinRegCurve(
  AldCor$Val[-grep("0", rownames(AldCor))],
  AldCor$ALD1_Aged[-grep("0", rownames(AldCor))],
  rownames(AldCor)[-grep("0", rownames(AldCor))],
  "Valine (mg/L)",
  "2-methylpropanal (g/L)",
  "SFig 1 - val_2MP_PLB",
  "SFig 1 lin reg curves/"
)
LinRegCurve(
  AldCor$Val[grep("0", rownames(AldCor))],
  AldCor$ALD1_Aged[grep("0", rownames(AldCor))],
  rownames(AldCor)[grep("0", rownames(AldCor))],
  "Valine (mg/L)",
  "2-methylpropanal (g/L)",
  "SFig 1 - val_2MP_NAB",
  "SFig 1 lin reg curves/"
)

#Ile-2MB
LinRegCurve(
  AldCor$Ile,
  AldCor$ALD2_Aged,
  rownames(AldCor),
  "Isoleucine (mg/L)",
  "2-methylbutanal (g/L)",
  "SFig 1 - ile_2MB_all",
  "SFig 1 lin reg curves/"
)
LinRegCurve(
  AldCor$Ile[-grep("0", rownames(AldCor))],
  AldCor$ALD2_Aged[-grep("0", rownames(AldCor))],
  rownames(AldCor)[-grep("0", rownames(AldCor))],
  "Isoleucine (mg/L)",
  "2-methylbutanal (g/L)",
  "SFig 1 - ile_2MB_PLB",
  "SFig 1 lin reg curves/"
)
LinRegCurve(
  AldCor$Ile[grep("0", rownames(AldCor))],
  AldCor$ALD2_Aged[grep("0", rownames(AldCor))],
  rownames(AldCor)[grep("0", rownames(AldCor))],
  "Isoleucine (mg/L)",
  "2-methylbutanal (g/L)",
  "SFig 1 - ile_2MB_NAB",
  "SFig 1 lin reg curves/"
)

#Leu-3MB
LinRegCurve(
  AldCor$Leu,
  AldCor$ALD3_Aged,
  rownames(AldCor),
  "Leucine (mg/L)",
  "3-methylbutanal (g/L)",
  "SFig 1 - Leu_3MB_all",
  "SFig 1 lin reg curves/"
)
LinRegCurve(
  AldCor$Leu[-grep("0", rownames(AldCor))],
  AldCor$ALD3_Aged[-grep("0", rownames(AldCor))],
  rownames(AldCor)[-grep("0", rownames(AldCor))],
  "Leucine (mg/L)",
  "3-methylbutanal (g/L)",
  "SFig 1 - Leu_3MB_PLB",
  "SFig 1 lin reg curves/"
)
LinRegCurve(
  AldCor$Leu[grep("0", rownames(AldCor))],
  AldCor$ALD3_Aged[grep("0", rownames(AldCor))],
  rownames(AldCor)[grep("0", rownames(AldCor))],
  "Leucine (mg/L)",
  "3-methylbutanal (g/L)",
  "SFig 1 - Leu_3MB_NAB",
  "SFig 1 lin reg curves/"
)
#Met-METH
LinRegCurve(
  AldCor$Met,
  AldCor$ALD8_Aged,
  rownames(AldCor),
  "Methionine (mg/L)",
  "Methional (g/L)",
  "SFig 1 - Met_METH_all",
  "SFig 1 lin reg curves/"
)
LinRegCurve(
  AldCor$Met[-grep("0", rownames(AldCor))],
  AldCor$ALD8_Aged[-grep("0", rownames(AldCor))],
  rownames(AldCor)[-grep("0", rownames(AldCor))],
  "Methionine (mg/L)",
  "Methional (g/L)",
  "SFig 1 - Met_METH_PLB",
  "SFig 1 lin reg curves/"
)
LinRegCurve(
  AldCor$Met[grep("0", rownames(AldCor))],
  AldCor$ALD8_Aged[grep("0", rownames(AldCor))],
  rownames(AldCor)[grep("0", rownames(AldCor))],
  "Methionine (mg/L)",
  "Methional (g/L)",
  "SFig 1 - Met_METH_NAB",
  "SFig 1 lin reg curves/"
)

#Phe-PHEN
LinRegCurve(
  AldCor$Phe,
  AldCor$ALD6_Aged,
  rownames(AldCor),
  "Phenylalanine (mg/L)",
  "Phenylacetaldehyde (g/L)",
  "SFig 1 - Phe_PHEN_all",
  "SFig 1 lin reg curves/"
)
LinRegCurve(
  AldCor$Phe[-grep("0", rownames(AldCor))],
  AldCor$ALD6_Aged[-grep("0", rownames(AldCor))],
  rownames(AldCor)[-grep("0", rownames(AldCor))],
  "Phenylalanine (mg/L)",
  "Phenylacetaldehyde (g/L)",
  "SFig 1 - Phe_PHEN_PLB",
  "SFig 1 lin reg curves/"
)
LinRegCurve(
  AldCor$Phe[grep("0", rownames(AldCor))],
  AldCor$ALD6_Aged[grep("0", rownames(AldCor))],
  rownames(AldCor)[grep("0", rownames(AldCor))],
  "Phenylalanine (mg/L)",
  "Phenylacetaldehyde (g/L)",
  "SFig 1 - Phe_PHEN_NAB",
  "SFig 1 lin reg curves/"
)

#Sum-FAN
AldCor$Sum<-AldCor$ALD1_Aged+AldCor$ALD2_Aged+AldCor$ALD3_Aged+AldCor$ALD6_Aged+AldCor$ALD8_Aged
LinRegCurve(
  AldCor$FAN,
  AldCor$Sum,
  rownames(AldCor),
  "FAN (mg/L)",
  "Sum Strecker aldehydes (g/L)",
  "SFig 1 - Sum_FAN_all",
  "SFig 1 lin reg curves/"
)
LinRegCurve(
  AldCor$FAN[-grep("0", rownames(AldCor))],
  AldCor$Sum[-grep("0", rownames(AldCor))],
  rownames(AldCor)[-grep("0", rownames(AldCor))],
  "FAN (mg/L)",
  "Sum Strecker aldehydes (g/L)",
  "SFig 1 - Sum_FAN_PLB",
  "SFig 1 lin reg curves/"
)
LinRegCurve(
  AldCor$FAN[grep("0", rownames(AldCor))],
  AldCor$Sum[grep("0", rownames(AldCor))],
  rownames(AldCor)[grep("0", rownames(AldCor))],
  "FAN (mg/L)",
  "Sum Strecker aldehydes (g/L)",
  "SFig 1 - Sum_FAN_NAB",
  "SFig 1 lin reg curves/"
)

#Furf-TBI
LinRegCurve(
  AldCor$TBI,
  AldCor$ALD5_Aged,
  rownames(AldCor),
  "TBI",
  "Furfural (g/L)",
  "SFig 1 - FURF_TBI_all",
  "SFig 1 lin reg curves/"
)
LinRegCurve(
  AldCor$TBI[-grep("0", rownames(AldCor))],
  AldCor$ALD5_Aged[-grep("0", rownames(AldCor))],
  rownames(AldCor)[-grep("0", rownames(AldCor))],
  "TBI",
  "Furfural (g/L)",
  "SFig 1 - FURF_TBI_PLB",
  "SFig 1 lin reg curves/"
)
LinRegCurve(
  AldCor$TBI[grep("0", rownames(AldCor))],
  AldCor$ALD5_Aged[grep("0", rownames(AldCor))],
  rownames(AldCor)[grep("0", rownames(AldCor))],
  "TBI",
  "Furfural (g/L)",
  "SFig 1 - FURF_TBI_NAB",
  "SFig 1 lin reg curves/"
)

#T2N-THOE
LinRegCurve(
  AldCor$THOE,
  AldCor$ALD7_Aged,
  rownames(AldCor),
  "Trihydroxy fatty acids (mg/L)",
  "Trans-2-nonenal (g/L)",
  "SFig 1 - T2N_THOE_all",
  "SFig 1 lin reg curves/"
)
LinRegCurve(
  AldCor$THOE[-grep("0", rownames(AldCor))],
  AldCor$ALD7_Aged[-grep("0", rownames(AldCor))],
  rownames(AldCor)[-grep("0", rownames(AldCor))],
  "Trihydroxy fatty acids (mg/L)",
  "Trans-2-nonenal (g/L)",
  "SFig 1 - T2N_THOE_PLB",
  "SFig 1 lin reg curves/"
)
LinRegCurve(
  AldCor$THOE[grep("0", rownames(AldCor))],
  AldCor$ALD7_Aged[grep("0", rownames(AldCor))],
  rownames(AldCor)[grep("0", rownames(AldCor))],
  "Trihydroxy fatty acids (mg/L)",
  "Trans-2-nonenal (g/L)",
  "SFig 1 - T2N_THOE_NAB",
  "SFig 1 lin reg curves/"
)

#HEX-THOE
LinRegCurve(
  AldCor$THOE,
  AldCor$ALD4_Aged,
  rownames(AldCor),
  "Trihydroxy fatty acids (mg/L)",
  "Hexanal (g/L)",
  "SFig 1 - HEX_THOE_all",
  "SFig 1 lin reg curves/"
)
LinRegCurve(
  AldCor$THOE[-grep("0", rownames(AldCor))],
  AldCor$ALD4_Aged[-grep("0", rownames(AldCor))],
  rownames(AldCor)[-grep("0", rownames(AldCor))],
  "Trihydroxy fatty acids (mg/L)",
  "Hexanal (g/L)",
  "SFig 1 - HEX_THOE_PLB",
  "SFig 1 lin reg curves/"
)
LinRegCurve(
  AldCor$THOE[grep("0", rownames(AldCor))],
  AldCor$ALD4_Aged[grep("0", rownames(AldCor))],
  rownames(AldCor)[grep("0", rownames(AldCor))],
  "Trihydroxy fatty acids (mg/L)",
  "Hexanal (g/L)",
  "SFig 1 - Hex_THOE_NAB",
  "SFig 1 lin reg curves/"
)

#plots with the exclusion of certain parameters
LinRegCurveExcl(
  AldCor$Phe,
  AldCor$ALD6_Aged,
  rownames(AldCor),
  "Phenylalanine (mg/L)",
  "Phenylacetaldehyde (g/L)",
  "SFig 1 - Phe_PHEN_all",
  "SFig 1 lin reg curves/",
  "A0"
)

LinRegCurveExcl(
  AldCor$Phe[grep("0", rownames(AldCor))],
  AldCor$ALD6_Aged[grep("0", rownames(AldCor))],
  rownames(AldCor[grep("0", rownames(AldCor)),]),
  "Phenylalanine (mg/L)",
  "Phenylacetaldehyde (g/L)",
  "SFig 1 - Phe_PHEN_NAB",
  "SFig 1 lin reg curves/",
  "A0"
)
LinRegCurveExcl(
  AldCor$TBI,
  AldCor$ALD5_Aged,
  rownames(AldCor),
  "TBI",
  "Furfural (g/L)",
  "SFig 1 - FURF_ALD5_all",
  "SFig 1 lin reg curves/",
  "E0"
)
LinRegCurveExcl(
  AldCor$TBI[grep("0", rownames(AldCor))],
  AldCor$ALD5_Aged[grep("0", rownames(AldCor))],
  rownames(AldCor[grep("0", rownames(AldCor)),]),
  "TBI",
  "Furfural (g/L)",
  "SFig 1 - FURF_ALD5_NAB",
  "SFig 1 lin reg curves/",
  "E0"
)

